@@ -4,7 +4,7 @@ from typing import Type, List, Dict, Optional, Any
 import numpy as np
 import copy
 from ensmallen import Graph
-from embiggen.transformers import NodeLabelPredictionTransformer, NodeTransformer
+from embiggen.embedding_transformers import NodeLabelPredictionTransformer, NodeTransformer
 from embiggen.utils.sklearn_utils import must_be_an_sklearn_classifier_model
 from embiggen.node_label_prediction.node_label_prediction_model import AbstractNodeLabelPredictionModel
 from embiggen.utils.abstract_models import abstract_class
