@@ -10,11 +10,12 @@ from tensorflow.keras.optimizers import \
 from ensmallen import Graph
 import tensorflow as tf
 from tensorflow.keras.utils import Sequence
-from embiggen.utils.abstract_gcn import AbstractGCN
+from embiggen.utils.abstract_gcn import AbstractGCN, abstract_class
 from embiggen.utils.normalize_model_structural_parameters import normalize_model_list_parameter
 from embiggen.node_label_prediction.node_label_prediction_model import AbstractNodeLabelPredictionModel
 
 
+@abstract_class
 class GCNNodeLabelPrediction(AbstractGCN, AbstractNodeLabelPredictionModel):
     """GCN model for node-label prediction."""
 
@@ -26,6 +27,7 @@ class GCNNodeLabelPrediction(AbstractGCN, AbstractNodeLabelPredictionModel):
         number_of_units_per_graph_convolution_layers: Union[int, List[int]] = 128,
         number_of_units_per_head_layer: Union[int, List[int]] = 128,
         dropout_rate: float = 0.1,
+        apply_norm: bool = False,
         optimizer: Union[str, Optimizer] = "adam",
         early_stopping_min_delta: float = 0.0001,
         early_stopping_patience: int = 30,
@@ -62,6 +64,9 @@ class GCNNodeLabelPrediction(AbstractGCN, AbstractNodeLabelPredictionModel):
         dropout_rate: float = 0.3
             Float between 0 and 1.
             Fraction of the input units to dropout.
+        apply_norm: bool = False
+            Whether to normalize the output of the convolution operations,
+            after applying the level activations.
         optimizer: str = "Adam"
             The optimizer to use while training the model.
         early_stopping_min_delta: float
@@ -118,6 +123,7 @@ class GCNNodeLabelPrediction(AbstractGCN, AbstractNodeLabelPredictionModel):
             number_of_graph_convolution_layers=number_of_graph_convolution_layers,
             number_of_units_per_graph_convolution_layers=number_of_units_per_graph_convolution_layers,
             dropout_rate=dropout_rate,
+            apply_norm=apply_norm,
             optimizer=optimizer,
             early_stopping_min_delta=early_stopping_min_delta,
             early_stopping_patience=early_stopping_patience,
@@ -170,7 +176,7 @@ class GCNNodeLabelPrediction(AbstractGCN, AbstractNodeLabelPredictionModel):
         model = Model(
             inputs=graph_convolution_model.inputs,
             outputs=output,
-            name=self.model_name()
+            name=self.model_name().replace(" ", "_")
         )
 
         model.compile(
@@ -181,7 +187,7 @@ class GCNNodeLabelPrediction(AbstractGCN, AbstractNodeLabelPredictionModel):
 
         return model
 
-    def get_output_classes(self, graph:Graph) ->int:
+    def get_output_classes(self, graph: Graph) -> int:
         """Returns number of output classes."""
         return graph.get_node_types_number()
 
@@ -264,7 +270,3 @@ class GCNNodeLabelPrediction(AbstractGCN, AbstractNodeLabelPredictionModel):
     def is_using_edge_types(self) -> bool:
         """Returns whether the model is parametrized to use edge types."""
         return False
-
-    @staticmethod
-    def model_name() -> str:
-        return "GCN"
\ No newline at end of file
